@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTENCLR"]
-pub type R = crate::R<u32, super::INTENCLR>;
-#[doc = "Writer for register INTENCLR"]
-pub type W = crate::W<u32, super::INTENCLR>;
-#[doc = "Register INTENCLR `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENCLR {
-    type Type = u32;
+#[doc = "Register `INTENCLR` reader"]
+pub struct R(crate::R<INTENCLR_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENCLR_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTENCLR_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENCLR_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENCLR` writer"]
+pub struct W(crate::W<INTENCLR_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENCLR_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENCLR_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENCLR_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Write '1' to disable interrupt for event HFCLKSTARTED\n\nValue on reset: 0"]
@@ -24,9 +48,12 @@ impl From<HFCLKSTARTED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `HFCLKSTARTED`"]
-pub type HFCLKSTARTED_R = crate::R<bool, HFCLKSTARTED_A>;
+#[doc = "Field `HFCLKSTARTED` reader - Write '1' to disable interrupt for event HFCLKSTARTED"]
+pub struct HFCLKSTARTED_R(crate::FieldReader<bool, HFCLKSTARTED_A>);
 impl HFCLKSTARTED_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        HFCLKSTARTED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> HFCLKSTARTED_A {
@@ -38,12 +65,19 @@ impl HFCLKSTARTED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == HFCLKSTARTED_A::DISABLED
+        **self == HFCLKSTARTED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == HFCLKSTARTED_A::ENABLED
+        **self == HFCLKSTARTED_A::ENABLED
+    }
+}
+impl core::ops::Deref for HFCLKSTARTED_R {
+    type Target = crate::FieldReader<bool, HFCLKSTARTED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event HFCLKSTARTED\n\nValue on reset: 0"]
@@ -58,7 +92,7 @@ impl From<HFCLKSTARTED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `HFCLKSTARTED`"]
+#[doc = "Field `HFCLKSTARTED` writer - Write '1' to disable interrupt for event HFCLKSTARTED"]
 pub struct HFCLKSTARTED_W<'a> {
     w: &'a mut W,
 }
@@ -66,9 +100,7 @@ impl<'a> HFCLKSTARTED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: HFCLKSTARTED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -88,7 +120,7 @@ impl<'a> HFCLKSTARTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -106,9 +138,12 @@ impl From<LFCLKSTARTED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LFCLKSTARTED`"]
-pub type LFCLKSTARTED_R = crate::R<bool, LFCLKSTARTED_A>;
+#[doc = "Field `LFCLKSTARTED` reader - Write '1' to disable interrupt for event LFCLKSTARTED"]
+pub struct LFCLKSTARTED_R(crate::FieldReader<bool, LFCLKSTARTED_A>);
 impl LFCLKSTARTED_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        LFCLKSTARTED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LFCLKSTARTED_A {
@@ -120,12 +155,19 @@ impl LFCLKSTARTED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == LFCLKSTARTED_A::DISABLED
+        **self == LFCLKSTARTED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == LFCLKSTARTED_A::ENABLED
+        **self == LFCLKSTARTED_A::ENABLED
+    }
+}
+impl core::ops::Deref for LFCLKSTARTED_R {
+    type Target = crate::FieldReader<bool, LFCLKSTARTED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event LFCLKSTARTED\n\nValue on reset: 0"]
@@ -140,7 +182,7 @@ impl From<LFCLKSTARTED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `LFCLKSTARTED`"]
+#[doc = "Field `LFCLKSTARTED` writer - Write '1' to disable interrupt for event LFCLKSTARTED"]
 pub struct LFCLKSTARTED_W<'a> {
     w: &'a mut W,
 }
@@ -148,9 +190,7 @@ impl<'a> LFCLKSTARTED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LFCLKSTARTED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -170,7 +210,7 @@ impl<'a> LFCLKSTARTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -188,9 +228,12 @@ impl From<DONE_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `DONE`"]
-pub type DONE_R = crate::R<bool, DONE_A>;
+#[doc = "Field `DONE` reader - Write '1' to disable interrupt for event DONE"]
+pub struct DONE_R(crate::FieldReader<bool, DONE_A>);
 impl DONE_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DONE_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DONE_A {
@@ -202,12 +245,19 @@ impl DONE_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == DONE_A::DISABLED
+        **self == DONE_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == DONE_A::ENABLED
+        **self == DONE_A::ENABLED
+    }
+}
+impl core::ops::Deref for DONE_R {
+    type Target = crate::FieldReader<bool, DONE_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event DONE\n\nValue on reset: 0"]
@@ -222,7 +272,7 @@ impl From<DONE_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `DONE`"]
+#[doc = "Field `DONE` writer - Write '1' to disable interrupt for event DONE"]
 pub struct DONE_W<'a> {
     w: &'a mut W,
 }
@@ -230,9 +280,7 @@ impl<'a> DONE_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: DONE_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -252,7 +300,7 @@ impl<'a> DONE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -270,9 +318,12 @@ impl From<CTTO_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CTTO`"]
-pub type CTTO_R = crate::R<bool, CTTO_A>;
+#[doc = "Field `CTTO` reader - Write '1' to disable interrupt for event CTTO"]
+pub struct CTTO_R(crate::FieldReader<bool, CTTO_A>);
 impl CTTO_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CTTO_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CTTO_A {
@@ -284,12 +335,19 @@ impl CTTO_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == CTTO_A::DISABLED
+        **self == CTTO_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == CTTO_A::ENABLED
+        **self == CTTO_A::ENABLED
+    }
+}
+impl core::ops::Deref for CTTO_R {
+    type Target = crate::FieldReader<bool, CTTO_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event CTTO\n\nValue on reset: 0"]
@@ -304,7 +362,7 @@ impl From<CTTO_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `CTTO`"]
+#[doc = "Field `CTTO` writer - Write '1' to disable interrupt for event CTTO"]
 pub struct CTTO_W<'a> {
     w: &'a mut W,
 }
@@ -312,9 +370,7 @@ impl<'a> CTTO_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CTTO_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -334,7 +390,7 @@ impl<'a> CTTO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -352,9 +408,12 @@ impl From<CTSTARTED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CTSTARTED`"]
-pub type CTSTARTED_R = crate::R<bool, CTSTARTED_A>;
+#[doc = "Field `CTSTARTED` reader - Write '1' to disable interrupt for event CTSTARTED"]
+pub struct CTSTARTED_R(crate::FieldReader<bool, CTSTARTED_A>);
 impl CTSTARTED_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CTSTARTED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CTSTARTED_A {
@@ -366,12 +425,19 @@ impl CTSTARTED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == CTSTARTED_A::DISABLED
+        **self == CTSTARTED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == CTSTARTED_A::ENABLED
+        **self == CTSTARTED_A::ENABLED
+    }
+}
+impl core::ops::Deref for CTSTARTED_R {
+    type Target = crate::FieldReader<bool, CTSTARTED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event CTSTARTED\n\nValue on reset: 0"]
@@ -386,7 +452,7 @@ impl From<CTSTARTED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `CTSTARTED`"]
+#[doc = "Field `CTSTARTED` writer - Write '1' to disable interrupt for event CTSTARTED"]
 pub struct CTSTARTED_W<'a> {
     w: &'a mut W,
 }
@@ -394,9 +460,7 @@ impl<'a> CTSTARTED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CTSTARTED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -416,7 +480,7 @@ impl<'a> CTSTARTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
@@ -434,9 +498,12 @@ impl From<CTSTOPPED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CTSTOPPED`"]
-pub type CTSTOPPED_R = crate::R<bool, CTSTOPPED_A>;
+#[doc = "Field `CTSTOPPED` reader - Write '1' to disable interrupt for event CTSTOPPED"]
+pub struct CTSTOPPED_R(crate::FieldReader<bool, CTSTOPPED_A>);
 impl CTSTOPPED_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CTSTOPPED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CTSTOPPED_A {
@@ -448,12 +515,19 @@ impl CTSTOPPED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == CTSTOPPED_A::DISABLED
+        **self == CTSTOPPED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == CTSTOPPED_A::ENABLED
+        **self == CTSTOPPED_A::ENABLED
+    }
+}
+impl core::ops::Deref for CTSTOPPED_R {
+    type Target = crate::FieldReader<bool, CTSTOPPED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to disable interrupt for event CTSTOPPED\n\nValue on reset: 0"]
@@ -468,7 +542,7 @@ impl From<CTSTOPPED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `CTSTOPPED`"]
+#[doc = "Field `CTSTOPPED` writer - Write '1' to disable interrupt for event CTSTOPPED"]
 pub struct CTSTOPPED_W<'a> {
     w: &'a mut W,
 }
@@ -476,9 +550,7 @@ impl<'a> CTSTOPPED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CTSTOPPED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -498,7 +570,7 @@ impl<'a> CTSTOPPED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
@@ -565,4 +637,30 @@ impl W {
     pub fn ctstopped(&mut self) -> CTSTOPPED_W {
         CTSTOPPED_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Disable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenclr](index.html) module"]
+pub struct INTENCLR_SPEC;
+impl crate::RegisterSpec for INTENCLR_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenclr::R](R) reader structure"]
+impl crate::Readable for INTENCLR_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenclr::W](W) writer structure"]
+impl crate::Writable for INTENCLR_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENCLR to value 0"]
+impl crate::Resettable for INTENCLR_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
