@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTENSET"]
-pub type R = crate::R<u32, super::INTENSET>;
-#[doc = "Writer for register INTENSET"]
-pub type W = crate::W<u32, super::INTENSET>;
-#[doc = "Register INTENSET `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENSET {
-    type Type = u32;
+#[doc = "Register `INTENSET` reader"]
+pub struct R(crate::R<INTENSET_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENSET_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTENSET_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENSET_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENSET` writer"]
+pub struct W(crate::W<INTENSET_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENSET_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENSET_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENSET_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Write '1' to enable interrupt for event POFWARN\n\nValue on reset: 0"]
@@ -24,9 +48,12 @@ impl From<POFWARN_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `POFWARN`"]
-pub type POFWARN_R = crate::R<bool, POFWARN_A>;
+#[doc = "Field `POFWARN` reader - Write '1' to enable interrupt for event POFWARN"]
+pub struct POFWARN_R(crate::FieldReader<bool, POFWARN_A>);
 impl POFWARN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        POFWARN_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> POFWARN_A {
@@ -38,12 +65,19 @@ impl POFWARN_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == POFWARN_A::DISABLED
+        **self == POFWARN_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == POFWARN_A::ENABLED
+        **self == POFWARN_A::ENABLED
+    }
+}
+impl core::ops::Deref for POFWARN_R {
+    type Target = crate::FieldReader<bool, POFWARN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event POFWARN\n\nValue on reset: 0"]
@@ -58,7 +92,7 @@ impl From<POFWARN_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `POFWARN`"]
+#[doc = "Field `POFWARN` writer - Write '1' to enable interrupt for event POFWARN"]
 pub struct POFWARN_W<'a> {
     w: &'a mut W,
 }
@@ -66,9 +100,7 @@ impl<'a> POFWARN_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: POFWARN_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -88,7 +120,7 @@ impl<'a> POFWARN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -106,9 +138,12 @@ impl From<SLEEPENTER_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `SLEEPENTER`"]
-pub type SLEEPENTER_R = crate::R<bool, SLEEPENTER_A>;
+#[doc = "Field `SLEEPENTER` reader - Write '1' to enable interrupt for event SLEEPENTER"]
+pub struct SLEEPENTER_R(crate::FieldReader<bool, SLEEPENTER_A>);
 impl SLEEPENTER_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SLEEPENTER_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SLEEPENTER_A {
@@ -120,12 +155,19 @@ impl SLEEPENTER_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == SLEEPENTER_A::DISABLED
+        **self == SLEEPENTER_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == SLEEPENTER_A::ENABLED
+        **self == SLEEPENTER_A::ENABLED
+    }
+}
+impl core::ops::Deref for SLEEPENTER_R {
+    type Target = crate::FieldReader<bool, SLEEPENTER_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event SLEEPENTER\n\nValue on reset: 0"]
@@ -140,7 +182,7 @@ impl From<SLEEPENTER_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `SLEEPENTER`"]
+#[doc = "Field `SLEEPENTER` writer - Write '1' to enable interrupt for event SLEEPENTER"]
 pub struct SLEEPENTER_W<'a> {
     w: &'a mut W,
 }
@@ -148,9 +190,7 @@ impl<'a> SLEEPENTER_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: SLEEPENTER_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -170,7 +210,7 @@ impl<'a> SLEEPENTER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
@@ -188,9 +228,12 @@ impl From<SLEEPEXIT_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `SLEEPEXIT`"]
-pub type SLEEPEXIT_R = crate::R<bool, SLEEPEXIT_A>;
+#[doc = "Field `SLEEPEXIT` reader - Write '1' to enable interrupt for event SLEEPEXIT"]
+pub struct SLEEPEXIT_R(crate::FieldReader<bool, SLEEPEXIT_A>);
 impl SLEEPEXIT_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SLEEPEXIT_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SLEEPEXIT_A {
@@ -202,12 +245,19 @@ impl SLEEPEXIT_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == SLEEPEXIT_A::DISABLED
+        **self == SLEEPEXIT_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == SLEEPEXIT_A::ENABLED
+        **self == SLEEPEXIT_A::ENABLED
+    }
+}
+impl core::ops::Deref for SLEEPEXIT_R {
+    type Target = crate::FieldReader<bool, SLEEPEXIT_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event SLEEPEXIT\n\nValue on reset: 0"]
@@ -222,7 +272,7 @@ impl From<SLEEPEXIT_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `SLEEPEXIT`"]
+#[doc = "Field `SLEEPEXIT` writer - Write '1' to enable interrupt for event SLEEPEXIT"]
 pub struct SLEEPEXIT_W<'a> {
     w: &'a mut W,
 }
@@ -230,9 +280,7 @@ impl<'a> SLEEPEXIT_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: SLEEPEXIT_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -252,7 +300,7 @@ impl<'a> SLEEPEXIT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
@@ -270,9 +318,12 @@ impl From<USBDETECTED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `USBDETECTED`"]
-pub type USBDETECTED_R = crate::R<bool, USBDETECTED_A>;
+#[doc = "Field `USBDETECTED` reader - Write '1' to enable interrupt for event USBDETECTED"]
+pub struct USBDETECTED_R(crate::FieldReader<bool, USBDETECTED_A>);
 impl USBDETECTED_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        USBDETECTED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> USBDETECTED_A {
@@ -284,12 +335,19 @@ impl USBDETECTED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == USBDETECTED_A::DISABLED
+        **self == USBDETECTED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == USBDETECTED_A::ENABLED
+        **self == USBDETECTED_A::ENABLED
+    }
+}
+impl core::ops::Deref for USBDETECTED_R {
+    type Target = crate::FieldReader<bool, USBDETECTED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event USBDETECTED\n\nValue on reset: 0"]
@@ -304,7 +362,7 @@ impl From<USBDETECTED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `USBDETECTED`"]
+#[doc = "Field `USBDETECTED` writer - Write '1' to enable interrupt for event USBDETECTED"]
 pub struct USBDETECTED_W<'a> {
     w: &'a mut W,
 }
@@ -312,9 +370,7 @@ impl<'a> USBDETECTED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: USBDETECTED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -334,7 +390,7 @@ impl<'a> USBDETECTED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -352,9 +408,12 @@ impl From<USBREMOVED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `USBREMOVED`"]
-pub type USBREMOVED_R = crate::R<bool, USBREMOVED_A>;
+#[doc = "Field `USBREMOVED` reader - Write '1' to enable interrupt for event USBREMOVED"]
+pub struct USBREMOVED_R(crate::FieldReader<bool, USBREMOVED_A>);
 impl USBREMOVED_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        USBREMOVED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> USBREMOVED_A {
@@ -366,12 +425,19 @@ impl USBREMOVED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == USBREMOVED_A::DISABLED
+        **self == USBREMOVED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == USBREMOVED_A::ENABLED
+        **self == USBREMOVED_A::ENABLED
+    }
+}
+impl core::ops::Deref for USBREMOVED_R {
+    type Target = crate::FieldReader<bool, USBREMOVED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event USBREMOVED\n\nValue on reset: 0"]
@@ -386,7 +452,7 @@ impl From<USBREMOVED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `USBREMOVED`"]
+#[doc = "Field `USBREMOVED` writer - Write '1' to enable interrupt for event USBREMOVED"]
 pub struct USBREMOVED_W<'a> {
     w: &'a mut W,
 }
@@ -394,9 +460,7 @@ impl<'a> USBREMOVED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: USBREMOVED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -416,7 +480,7 @@ impl<'a> USBREMOVED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
@@ -434,9 +498,12 @@ impl From<USBPWRRDY_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `USBPWRRDY`"]
-pub type USBPWRRDY_R = crate::R<bool, USBPWRRDY_A>;
+#[doc = "Field `USBPWRRDY` reader - Write '1' to enable interrupt for event USBPWRRDY"]
+pub struct USBPWRRDY_R(crate::FieldReader<bool, USBPWRRDY_A>);
 impl USBPWRRDY_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        USBPWRRDY_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> USBPWRRDY_A {
@@ -448,12 +515,19 @@ impl USBPWRRDY_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == USBPWRRDY_A::DISABLED
+        **self == USBPWRRDY_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == USBPWRRDY_A::ENABLED
+        **self == USBPWRRDY_A::ENABLED
+    }
+}
+impl core::ops::Deref for USBPWRRDY_R {
+    type Target = crate::FieldReader<bool, USBPWRRDY_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event USBPWRRDY\n\nValue on reset: 0"]
@@ -468,7 +542,7 @@ impl From<USBPWRRDY_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `USBPWRRDY`"]
+#[doc = "Field `USBPWRRDY` writer - Write '1' to enable interrupt for event USBPWRRDY"]
 pub struct USBPWRRDY_W<'a> {
     w: &'a mut W,
 }
@@ -476,9 +550,7 @@ impl<'a> USBPWRRDY_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: USBPWRRDY_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -498,7 +570,7 @@ impl<'a> USBPWRRDY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
@@ -565,4 +637,30 @@ impl W {
     pub fn usbpwrrdy(&mut self) -> USBPWRRDY_W {
         USBPWRRDY_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Enable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenset](index.html) module"]
+pub struct INTENSET_SPEC;
+impl crate::RegisterSpec for INTENSET_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenset::R](R) reader structure"]
+impl crate::Readable for INTENSET_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenset::W](W) writer structure"]
+impl crate::Writable for INTENSET_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENSET to value 0"]
+impl crate::Resettable for INTENSET_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
