@@ -1,13 +1,37 @@
-#[doc = "Reader of register RESETREAS"]
-pub type R = crate::R<u32, super::RESETREAS>;
-#[doc = "Writer for register RESETREAS"]
-pub type W = crate::W<u32, super::RESETREAS>;
-#[doc = "Register RESETREAS `reset()`'s with value 0"]
-impl crate::ResetValue for super::RESETREAS {
-    type Type = u32;
+#[doc = "Register `RESETREAS` reader"]
+pub struct R(crate::R<RESETREAS_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<RESETREAS_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<RESETREAS_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<RESETREAS_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `RESETREAS` writer"]
+pub struct W(crate::W<RESETREAS_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<RESETREAS_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<RESETREAS_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<RESETREAS_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Reset from pin-reset detected\n\nValue on reset: 0"]
@@ -24,9 +48,12 @@ impl From<RESETPIN_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `RESETPIN`"]
-pub type RESETPIN_R = crate::R<bool, RESETPIN_A>;
+#[doc = "Field `RESETPIN` reader - Reset from pin-reset detected"]
+pub struct RESETPIN_R(crate::FieldReader<bool, RESETPIN_A>);
 impl RESETPIN_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        RESETPIN_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RESETPIN_A {
@@ -38,15 +65,22 @@ impl RESETPIN_R {
     #[doc = "Checks if the value of the field is `NOTDETECTED`"]
     #[inline(always)]
     pub fn is_not_detected(&self) -> bool {
-        *self == RESETPIN_A::NOTDETECTED
+        **self == RESETPIN_A::NOTDETECTED
     }
     #[doc = "Checks if the value of the field is `DETECTED`"]
     #[inline(always)]
     pub fn is_detected(&self) -> bool {
-        *self == RESETPIN_A::DETECTED
+        **self == RESETPIN_A::DETECTED
     }
 }
-#[doc = "Write proxy for field `RESETPIN`"]
+impl core::ops::Deref for RESETPIN_R {
+    type Target = crate::FieldReader<bool, RESETPIN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RESETPIN` writer - Reset from pin-reset detected"]
 pub struct RESETPIN_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +88,7 @@ impl<'a> RESETPIN_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RESETPIN_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Not detected"]
     #[inline(always)]
@@ -81,7 +113,7 @@ impl<'a> RESETPIN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -99,9 +131,12 @@ impl From<DOG_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `DOG`"]
-pub type DOG_R = crate::R<bool, DOG_A>;
+#[doc = "Field `DOG` reader - Reset from watchdog detected"]
+pub struct DOG_R(crate::FieldReader<bool, DOG_A>);
 impl DOG_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DOG_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DOG_A {
@@ -113,15 +148,22 @@ impl DOG_R {
     #[doc = "Checks if the value of the field is `NOTDETECTED`"]
     #[inline(always)]
     pub fn is_not_detected(&self) -> bool {
-        *self == DOG_A::NOTDETECTED
+        **self == DOG_A::NOTDETECTED
     }
     #[doc = "Checks if the value of the field is `DETECTED`"]
     #[inline(always)]
     pub fn is_detected(&self) -> bool {
-        *self == DOG_A::DETECTED
+        **self == DOG_A::DETECTED
     }
 }
-#[doc = "Write proxy for field `DOG`"]
+impl core::ops::Deref for DOG_R {
+    type Target = crate::FieldReader<bool, DOG_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DOG` writer - Reset from watchdog detected"]
 pub struct DOG_W<'a> {
     w: &'a mut W,
 }
@@ -129,9 +171,7 @@ impl<'a> DOG_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: DOG_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Not detected"]
     #[inline(always)]
@@ -156,7 +196,7 @@ impl<'a> DOG_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -174,9 +214,12 @@ impl From<SREQ_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `SREQ`"]
-pub type SREQ_R = crate::R<bool, SREQ_A>;
+#[doc = "Field `SREQ` reader - Reset from soft reset detected"]
+pub struct SREQ_R(crate::FieldReader<bool, SREQ_A>);
 impl SREQ_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SREQ_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SREQ_A {
@@ -188,15 +231,22 @@ impl SREQ_R {
     #[doc = "Checks if the value of the field is `NOTDETECTED`"]
     #[inline(always)]
     pub fn is_not_detected(&self) -> bool {
-        *self == SREQ_A::NOTDETECTED
+        **self == SREQ_A::NOTDETECTED
     }
     #[doc = "Checks if the value of the field is `DETECTED`"]
     #[inline(always)]
     pub fn is_detected(&self) -> bool {
-        *self == SREQ_A::DETECTED
+        **self == SREQ_A::DETECTED
     }
 }
-#[doc = "Write proxy for field `SREQ`"]
+impl core::ops::Deref for SREQ_R {
+    type Target = crate::FieldReader<bool, SREQ_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SREQ` writer - Reset from soft reset detected"]
 pub struct SREQ_W<'a> {
     w: &'a mut W,
 }
@@ -204,9 +254,7 @@ impl<'a> SREQ_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: SREQ_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Not detected"]
     #[inline(always)]
@@ -231,7 +279,7 @@ impl<'a> SREQ_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -249,9 +297,12 @@ impl From<LOCKUP_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `LOCKUP`"]
-pub type LOCKUP_R = crate::R<bool, LOCKUP_A>;
+#[doc = "Field `LOCKUP` reader - Reset from CPU lock-up detected"]
+pub struct LOCKUP_R(crate::FieldReader<bool, LOCKUP_A>);
 impl LOCKUP_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        LOCKUP_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LOCKUP_A {
@@ -263,15 +314,22 @@ impl LOCKUP_R {
     #[doc = "Checks if the value of the field is `NOTDETECTED`"]
     #[inline(always)]
     pub fn is_not_detected(&self) -> bool {
-        *self == LOCKUP_A::NOTDETECTED
+        **self == LOCKUP_A::NOTDETECTED
     }
     #[doc = "Checks if the value of the field is `DETECTED`"]
     #[inline(always)]
     pub fn is_detected(&self) -> bool {
-        *self == LOCKUP_A::DETECTED
+        **self == LOCKUP_A::DETECTED
     }
 }
-#[doc = "Write proxy for field `LOCKUP`"]
+impl core::ops::Deref for LOCKUP_R {
+    type Target = crate::FieldReader<bool, LOCKUP_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LOCKUP` writer - Reset from CPU lock-up detected"]
 pub struct LOCKUP_W<'a> {
     w: &'a mut W,
 }
@@ -279,9 +337,7 @@ impl<'a> LOCKUP_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: LOCKUP_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Not detected"]
     #[inline(always)]
@@ -306,7 +362,7 @@ impl<'a> LOCKUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -324,9 +380,12 @@ impl From<OFF_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `OFF`"]
-pub type OFF_R = crate::R<bool, OFF_A>;
+#[doc = "Field `OFF` reader - Reset due to wake up from System OFF mode when wakeup is triggered from DETECT signal from GPIO"]
+pub struct OFF_R(crate::FieldReader<bool, OFF_A>);
 impl OFF_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        OFF_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> OFF_A {
@@ -338,15 +397,22 @@ impl OFF_R {
     #[doc = "Checks if the value of the field is `NOTDETECTED`"]
     #[inline(always)]
     pub fn is_not_detected(&self) -> bool {
-        *self == OFF_A::NOTDETECTED
+        **self == OFF_A::NOTDETECTED
     }
     #[doc = "Checks if the value of the field is `DETECTED`"]
     #[inline(always)]
     pub fn is_detected(&self) -> bool {
-        *self == OFF_A::DETECTED
+        **self == OFF_A::DETECTED
     }
 }
-#[doc = "Write proxy for field `OFF`"]
+impl core::ops::Deref for OFF_R {
+    type Target = crate::FieldReader<bool, OFF_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OFF` writer - Reset due to wake up from System OFF mode when wakeup is triggered from DETECT signal from GPIO"]
 pub struct OFF_W<'a> {
     w: &'a mut W,
 }
@@ -354,9 +420,7 @@ impl<'a> OFF_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: OFF_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Not detected"]
     #[inline(always)]
@@ -381,7 +445,7 @@ impl<'a> OFF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
@@ -399,9 +463,12 @@ impl From<DIF_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `DIF`"]
-pub type DIF_R = crate::R<bool, DIF_A>;
+#[doc = "Field `DIF` reader - Reset due to wake up from System OFF mode when wakeup is triggered from entering into debug interface mode"]
+pub struct DIF_R(crate::FieldReader<bool, DIF_A>);
 impl DIF_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DIF_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DIF_A {
@@ -413,15 +480,22 @@ impl DIF_R {
     #[doc = "Checks if the value of the field is `NOTDETECTED`"]
     #[inline(always)]
     pub fn is_not_detected(&self) -> bool {
-        *self == DIF_A::NOTDETECTED
+        **self == DIF_A::NOTDETECTED
     }
     #[doc = "Checks if the value of the field is `DETECTED`"]
     #[inline(always)]
     pub fn is_detected(&self) -> bool {
-        *self == DIF_A::DETECTED
+        **self == DIF_A::DETECTED
     }
 }
-#[doc = "Write proxy for field `DIF`"]
+impl core::ops::Deref for DIF_R {
+    type Target = crate::FieldReader<bool, DIF_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DIF` writer - Reset due to wake up from System OFF mode when wakeup is triggered from entering into debug interface mode"]
 pub struct DIF_W<'a> {
     w: &'a mut W,
 }
@@ -429,9 +503,7 @@ impl<'a> DIF_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: DIF_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Not detected"]
     #[inline(always)]
@@ -456,7 +528,7 @@ impl<'a> DIF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
@@ -474,9 +546,12 @@ impl From<VBUS_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `VBUS`"]
-pub type VBUS_R = crate::R<bool, VBUS_A>;
+#[doc = "Field `VBUS` reader - Reset due to wake up from System OFF mode by VBUS rising into valid range"]
+pub struct VBUS_R(crate::FieldReader<bool, VBUS_A>);
 impl VBUS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        VBUS_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> VBUS_A {
@@ -488,15 +563,22 @@ impl VBUS_R {
     #[doc = "Checks if the value of the field is `NOTDETECTED`"]
     #[inline(always)]
     pub fn is_not_detected(&self) -> bool {
-        *self == VBUS_A::NOTDETECTED
+        **self == VBUS_A::NOTDETECTED
     }
     #[doc = "Checks if the value of the field is `DETECTED`"]
     #[inline(always)]
     pub fn is_detected(&self) -> bool {
-        *self == VBUS_A::DETECTED
+        **self == VBUS_A::DETECTED
     }
 }
-#[doc = "Write proxy for field `VBUS`"]
+impl core::ops::Deref for VBUS_R {
+    type Target = crate::FieldReader<bool, VBUS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `VBUS` writer - Reset due to wake up from System OFF mode by VBUS rising into valid range"]
 pub struct VBUS_W<'a> {
     w: &'a mut W,
 }
@@ -504,9 +586,7 @@ impl<'a> VBUS_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: VBUS_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Not detected"]
     #[inline(always)]
@@ -531,7 +611,7 @@ impl<'a> VBUS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
@@ -608,4 +688,30 @@ impl W {
     pub fn vbus(&mut self) -> VBUS_W {
         VBUS_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Reset reason\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [resetreas](index.html) module"]
+pub struct RESETREAS_SPEC;
+impl crate::RegisterSpec for RESETREAS_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [resetreas::R](R) reader structure"]
+impl crate::Readable for RESETREAS_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [resetreas::W](W) writer structure"]
+impl crate::Writable for RESETREAS_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets RESETREAS to value 0"]
+impl crate::Resettable for RESETREAS_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
